@@ -5,6 +5,7 @@ from collections import namedtuple
 from monolith.compat import OrderedDict
 from monolith.compat import unicode
 from monolith.cli.exceptions import AlreadyRegistered
+from monolith.cli.exceptions import CommandError
 from monolith.utils.imports import get_class
 
 
@@ -77,6 +78,7 @@ class ExecutionManager(object):
             cmdparser = subparsers.add_parser(name, help=command.help)
             for argument in command.get_args():
                 cmdparser.add_argument(*argument.args, **argument.kwargs)
+            command.setup_parser(parser, cmdparser)
             cmdparser.set_defaults(func=command.handle)
 
         return parser
@@ -129,7 +131,7 @@ class ExecutionManager(object):
         parser = self.get_parser()
         args = [cmd] + list(argv)
         namespace = parser.parse_args(args)
-        namespace.func(namespace)
+        self.run_command(namespace)
 
     def execute(self, argv=None):
         """
@@ -140,7 +142,14 @@ class ExecutionManager(object):
         parser = self.get_parser()
         namespace = parser.parse_args(argv)
         if hasattr(namespace, 'func'):
+            self.run_command(namespace)
+
+    def run_command(self, namespace):
+        try:
             namespace.func(namespace)
+        except CommandError as err:
+            sys.stderr.write('ERROR: %s\n' % err.message)
+            sys.exit(err.code)
 
     def autocomplete(self):
         """
@@ -218,6 +227,17 @@ class BaseCommand(object):
         """
         return self.args or []
 
+    def setup_parser(self, parser, cmdparser):
+        """
+        This would be called when command is registered by ExecutionManager
+        after arguments from ``get_args`` are processed.
+
+        Default implementation does nothing.
+
+        :param parser: Global argparser.ArgumentParser
+        :param cmdparser: Subparser related with this command
+        """
+
     def handle(self, namespace):
         """
         Handles given ``namespace`` and executes command. Should be overridden
